/// <reference types="node" resolution-mode="require"/>
import { ABIParameter, ABIType } from '@aztec/foundation/abi';
/**
 * Generate a function signature string for a given function name and parameters.
 * The signature is used to uniquely identify functions within noir contracts.
 * If the function name is 'constructor', it returns just the name, otherwise it returns the name followed by the list of parameter types.
 *
 * @param name - The name of the function.
 * @param parameters - An array of ABIParameter objects, each containing the type information of a function parameter.
 * @returns A string representing the function signature.
 */
export declare function computeFunctionSignature(name: string, parameters: ABIParameter[]): string;
/**
 * Generate a function selector for a given function signature.
 * @param signature - The signature of the function.
 * @param size - Number of bytes of the return buffer.
 * @returns A Buffer containing the n-byte function selector.
 */
export declare function computeFunctionSelector(signature: string, size: number): Buffer;
/**
 * Generate a function selector for a given function name and parameters.
 * It is derived by taking the first 4 bytes of the Keccak-256 hash of the function signature.
 *
 * @param name - The name of the function.
 * @param parameters - An array of ABIParameter objects, each containing the type information of a function parameter.
 * @returns A Buffer containing the 4-byte function selector.
 */
export declare function generateFunctionSelector(name: string, parameters: ABIParameter[]): Buffer;
/**
 * Get the size of an ABI type in field elements.
 * @param type - The ABI type.
 * @returns The size of the type in field elements.
 */
export declare function sizeOfType(type: ABIType): number;
//# sourceMappingURL=abi_coder.d.ts.map